@@ -50,6 +50,10 @@ AnnotationHub <-
         message("Cannot connect to AnnotationHub server, using 'localHub=TRUE' instead")
         localHub <- !connect
     }
+    if(localHub){
+        message("Using 'localHub=TRUE'\n",
+                "  If offline, please also see BiocManager vignette section on offline use")
+    }
     .Hub("AnnotationHub", hub, cache, proxy, localHub, ask, ...)
 }
 
