@@ -20,7 +20,7 @@ setClass("Hub",
 ### Constructor for subclasses
 ###
 
-.Hub <- function(.class, url, cache, proxy, localHub=FALSE, ask=TRUE, ...) {
+.Hub <- function(.class, url, cache, proxy, localHub=FALSE, ask=interactive(), ...) {
 
     # create or use cache location
     # download hub sqlite file and add/update to BiocFileCache for tracking
@@ -250,31 +250,6 @@ setMethod("[", c("Hub", "character", "missing"),
     x
 })
 
-setReplaceMethod("[", c("Hub", "numeric", "missing", "Hub"),
-    function(x, i, j, ..., value)
-{
-    .db_uid(x)[i] <- .db_uid(value)
-    x
-})
-
-setReplaceMethod("[", c("Hub", "logical", "missing", "Hub"),
-    function(x, i, j, ..., value)
-{
-    .db_uid(x)[i] <- .db_uid(value)
-    x
-})
-
-setReplaceMethod("[",
-    c("Hub", "character", "missing", "Hub"),
-    function(x, i, j, ..., value)
-{
-    idx <- match(i, names(.db_uid(x)))
-    isNA <- is.na(idx)
-    .db_uid(x)[idx[!isNA]] <- .db_uid(value)[!isNA]
-    x
-})
-
-
 setMethod("[[", c("Hub", "numeric", "missing"),
     function(x, i, j, ..., force=FALSE, verbose=TRUE)
 {
@@ -299,9 +274,22 @@ setMethod("[[", c("Hub", "character", "missing"),
                 as.Date(snapshotDate(x))))
             stop(status$record, " added after current Hub snapshot date.\n",
                  "  added: ", as.character(status$dateadded), "\n",
-                 "  snapshote date: ",  as.character(snapshotDate(x)),
+                 "  snapshot date: ",  as.character(snapshotDate(x)), "\n",
+                 "  To access this resource update your version of Bioconductor",
                  call.=FALSE)
 
+        if (status$status == "Public"){
+            details = getInfoOnIds(x,i)
+            if(details$rdataclass == "OrgDb")
+                stop(details$ah_id, " is an OrgDb resource.\n",
+                     "  orgDb resources are generated for specific biocversions.\n",
+                     "  Requested resource works with biocversion: ",
+                     details$biocversion,"\n",
+                     "  To find a resource appropriate for your biocversion try the following query:\n",
+                     "      query(ah,'", details$title, "')",
+                     call.=FALSE)
+        }
+
         msg <- paste0(status$status, "\n")
         if(!is.null(status$dateremoved))
             msg <- paste0(msg, "   Resource removed on: ", status$dateremoved)
@@ -706,8 +694,10 @@ setMethod("show", "Hub", function(object)
     object[idx]
 }
 
-setMethod("display", signature(object="Hub"),
-          function(object) .display(object)
+setMethod("display", signature(object="Hub"), function(object) {
+        .Deprecated(msg = "display,Hub-method is deprecated.")
+        .display(object)
+    }
 )
 
 
