@@ -169,6 +169,7 @@ DispatchClassList <- function(){
       "RDS", "readRDS()",
       "Rda", "get(load())",
       "data.frame", "get(load())",
+      "dcf", "read.dcf()",
       "GRanges", "get(load()); requires GenomicRanges",
       "VCF", "get(load()); requires VariantAnnotation",
       "ChainFile",
@@ -210,6 +211,7 @@ DispatchClassList <- function(){
       "mzRpwiz", "mzR::openMSfile(); require mzR",
       "mzRident", "mzR::openIDfile(); require mzR",
       "MSnSet", "get(load()); require MSnbase",
-      "AAStringSet", "Biostrings::readAAStringSet(); require Biostrings"
+      "AAStringSet", "Biostrings::readAAStringSet(); require Biostrings",
+      "CompDb", "CompoundDb::Compdb(); requires CompoundDb"
       ),  ncol=2, byrow=TRUE)
 }
